@@ -53,6 +53,7 @@ class Engine(Enum):
     GoogleMaps = "https://www.google.com/maps/search/{query}"
     GoogleNews = "https://news.google.com/search?q={query}"
     GooglePlayStore = "https://play.google.com/store/search?q={query}"
+    GoogleScholar = "https://scholar.google.com/scholar?q={query}"
     Genius = "https://www.genius.com/search?q={query}"
     HP = "https://www.hp.com/us-en/search.html#qt={query}"
     Hoogle = "https://hoogle.haskell.org/?hoogle={query}"
@@ -62,6 +63,7 @@ class Engine(Enum):
     Instagram = "https://www.instagram.com/{query}"
     InstantGaming = "https://www.instant-gaming.com/en/search/?q={query}"
     iStock = "https://www.istockphoto.com/search/2/image?family=creative&phrase={query}"
+    InternetArchive = "https://archive.org/search.php?query={query}"
     JetBrains = "https://www.jetbrains.com/search/?q={query}"
     LeetCode = "https://leetcode.com/problemset/all/?search={query}"
     Lenovo = "https://www.lenovo.com/us/en/search?fq=&text={query}"
@@ -76,6 +78,7 @@ class Engine(Enum):
     OpenLibrary = "https://openlibrary.org/search?q={query}"
     OperaAddons = "https://addons.opera.com/en/search/?query={query}"
     Pexels = "https://www.pexels.com/search/{query}"
+    Pinterest = "https://www.pinterest.com/search/pins/?q={query}"
     PyPi = "https://pypi.org/search/?q={query}"
     Quora = "https://www.quora.com/search?q={query}"
     Reddit = "https://www.reddit.com/search/?q={query}"
